## 0.1.0.2 (2023-01-14)

Update various comments now non-types dependencies are allowed (#9527)

## 0.1.0.1 (2022-11-11)

Add the ability to run third-party stubtest on Windows or MacOS when needed (#8923)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 0.1.0 (2022-09-12)

Add stubs for D3DShot (#8652)

